do crwork  // load data

cap program drop lik
program define lik
args lnf xb a0 a1 a2
tempvar index
	qui gen double `index' = `a0' + `a1' * (`xb' + refvar) + `a2' * (`xb' + refvar)^2
	qui replace `lnf' = q * `index' - log(1 + exp(`index'))
	//qui replace `lnf' = log(normal(`index')) * q + log(1 - normal(`index')) * (1 - q)
end

cap program drop est2step
program define est2step, eclass
syntax [if], AMEN1(varlist) AMEN0(varlist) [Z(string) XVARS(varlist) AX1(varlist) NOAHET PLOGIT MRATIO]
	marksample touse
	//markout `touse' `amen1' `amen0' `xvars' `z' `ax1'
	tempname alpha ALPHA psi psi_a pref b 
	tempvar xb
	local na : word count `amen0'
	local nx : word count `xvars'
	local nz : word count `z'
	// estimate mobility equation + mill's ratio (mr)
	if ("`plogit'"=="") {
		qui probit q `amen0' `xvars' `z' `ax1' if `touse'
		predict `xb', xb
		matrix `psi' = e(b)	
		gen mr = normalden(`xb') / normal(`xb')
	}
	if ("`plogit'"!="") {
		qui logit q `amen0' `xvars' `z' `ax1' refvar if `touse'
		matrix M = e(b)
		matrix M = M[1, 1.. colsof(M) - 2] / M[1, colsof(M) - 1], M[1, colsof(M)], 1, 0
		ml model lf lik (xb: `amen0' `xvars' `z' `ax1', nocons) (a0:) (a1:) (a2:) if `touse', technique(bhhh 15 bfgs 10)
		ml init M, copy		
		ml max
		matrix `psi' = e(b)
		predict mr, equation(#1)
		predict a0, equation(#2)
		replace mr = mr + refvar + a0
		matrix `psi_a' = `psi'[1, colsof(`psi')-2.. colsof(`psi')]
		matrix colnames `psi_a' = "a0" "a1" "a2"
		matrix `psi' = `psi'[1,1..`na' + `nx' + `nz'], `psi_a'
	}
	matrix coleq `psi' = psi
	if ("`mratio'"!="") {
		qui probit q mr if `touse'
		qui predict `xb', xb
		qui replace mr = normalden(`xb')/normal(`xb')
	}
	gen mr2 = mr^2
	// estimate offer equations
	if ("`noahet'"!="") local ax1	
	qui foreach vv of varlist `amen1' {
		reg `vv' `amen0' `xvars' mr* refvar `ax1' if q==1 & `touse'
		matrix `b' = e(b)
		matrix coleq `b' = `vv'		
		cap matrix `alpha' = `alpha' , `b'[1, 1..`na'+`nx'+1]
		if (_rc) matrix `alpha' = `b'[1, 1..`na'+`nx'+1]
	}
	// recuperate preferences
	mata: st_matrix("`ALPHA'", rowshape(st_matrix("`alpha'"), `na')) 
	matrix `pref' = `psi'[1,1..`na'] * inv(`ALPHA'[1...,1..`na'] - diag(J(1,`na',1)))
	matrix colnames `pref' = `amen0'
	matrix coleq `pref' = pref
	// return everything in one coef vector
	matrix `b' = `pref', `psi', `alpha'
	ereturn post `b', esample(`touse')
	ereturn local cmd="bootstrap"
	//estout, unstack cells(b(fmt(3)))   // for vertical output use: ereturn display
	cap drop mr* a0
end

cap program drop amenities
program amenities
syntax [anything] [if] [, BS] *
	marksample touse
	// are we bootstrapping? if so, std.error in table
	if ("`bs'"!="") {
		local bootstrap "bootstrap , reps(499) cluster(schoolid) notable: "
		//local bootstrap "bootstrap , reps(199) notable: "
		local se "se(par)"
	}
	// estimate
	`bootstrap' est2step if `touse', `options'
	// save and print table
	if ("`anything'"!="") est save `anything', replace
	estout, unstack cells(b(fmt(3) star) `se')
end


// comment out if we do not want to bootstrap
local bs bs

replace tzbud = tzbud / 1000
replace dzbud = dzbud / 1000

// BASIC SPECIFICATION:
unab amen1 : FIpdm FIpdd FIcs FIwtfactor FIpopkm2 FIpub FIpcito FIasch FIvsch FIrst
unab amen0 : FSpdm FSpdd FScs FSwtfactor FSpopkm2 FSpub FSpcito FSasch FSvsch FSrst
unab z : zbud zbaby 
unab xvars : age21-age25 age_d1 age_d2 age_d3 lnw baby rktendv FStemp tzbud trpcito dzbud drpcito noord zuid oost wwperc vacat werk dwerk
unab xvars : age21-age25 age_d1 age_d2 age_d3 lnw baby rktendv tzbud trpcito dzbud drpcito noord zuid oost wwperc vacat werk dwerk
gen refvar = FStemp

local aa1
qui foreach v of varlist `amen0'{
	bys stamnr (year): gen `v'_1 = `v'[1]
	local aa1 `aa1' `v'_1
}


local xx1
qui foreach v of varlist `xvars' {
	bys stamnr (year): gen `v'_1 = `v'[1]
	local xx1 `xx1' `v'_1
}

// MAIN RESULT, without heterogeneity
local bs bs

// TABLE 8
//probit q `amen0' `xvars' `z'
keep q `amen1' `amen0' `xvars' `z' `aa1' `xx1' refvar schoolid
amenities _nohet_plogit , `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z') plogit

// no excluded variable
local z = ""
unab xvars : age21-age25 age_d1 age_d2 age_d3 lnw baby rktendv tzbud trpcito dzbud drpcito zbaby zbud
amenities _nohet_plogit_znone , `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z') plogit


