set matsize 800
set seed 1290123957
set linesize 255

do crwork // load data

do progs  // load estimation progs


/* uncomment for figure */
/*
preserve
g ft = FSwtfact>= 1
collapse ft baby, by(age)
twoway connected (ft baby age), scheme(s1mono) xtitle(Age) ytitle(Fraction) mc(red blue) lp(solid shortdash) legend(off)
gr play fulltimeage
gr export fulltimeage.eps, replace
restore
*/


////////////////////////
// MAIN SPECIFICATION //
////////////////////////

unab amen1 : FIpdm FIpdd FIcs FIwtfactor FIpopkm2 FIpub FIpcito FIasch FIvsch FIrst
unab amen0 : FSpdm FSpdd FScs FSwtfactor FSpopkm2 FSpub FSpcito FSasch FSvsch FSrst
unab xvars : age21-age25 age_d1 age_d2 age_d3 lnw baby rktendv FStemp tzbud trpcito dzbud drpcito noord zuid oost wwperc vacatbb werkloosheid_perc dwerkloosheid
unab z     : zbud zbaby 

local bs bs


// DESCRIPTIVE STATISTICS

// TABLE 1
tabstat age age_* q baby, format(%6.3f) c(s)
codebook stamnr

// TABLE 2
tabstat `amen0', format(%6.3f) s(mean sd) c(s)
sum zbud, detail
sum zbud if zbud <= 0
sum zbud if zbud > 0
sum zbaby, detail
sum zbaby if zbaby <= 0
sum zbaby if zbaby > 0

codebook brin
bys brin year: g nteachers = _N if _n==1
bys brin year: g fteteachers = sum(FSwtfactor)
bys brin year: replace fteteachers = . if _n<_N
sum nteach fteteach
drop nteach fteteach


//////////////////
// MAIN RESULTS //
//////////////////

// initial conditions
local aa1
qui foreach vv of varlist `amen0'{
	bys stamnr (year): gen `vv'_1 = `vv'[1]
	local aa1 `aa1' `vv'_1
}

local xx1
qui foreach vv of varlist `xvars' {
	bys stamnr (year): gen `vv'_1 = `vv'[1]
	local xx1 `xx1' `vv'_1
}


// no unobserved heterogeneity
qui amenities _nohet , `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z')

// TABLE 3
esttab, unstack keep(pref:FS* psi:FS*) 
// TABLE 4
esttab, unstack keep(FI*:FS*) 
// APPENDIX TABLE B1
esttab, keep(psi:*)  wide se

// TABLE 5
unab amen0 : FSpdm FSpdd FScs FSwtfactor FSpopkm2 FSpub FSpcito FSasch FSvsch FSrst
qui foreach v of var `amen0' {
		nlcom _b[pref:`v'] / _b[pref:FScs]
		noi di "`v'" _col(15) %6.1f trace(r(b)) %6.1f sqrt(trace(r(V))) _c
		nlcom _b[psi:`v'] / _b[psi:FScs]
		noi di       _col(15) %6.1f trace(r(b)) %6.1f sqrt(trace(r(V)))
}

///////////////////////
// ROBUSTNESS CHECKS //
///////////////////////

// TABLE 6: unobserved heterogeneity a la Wooldridge (correlated random effects)
qui amenities _het_cre_x1 , `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z') ax1(`xx1')
esttab, unstack keep(pref:FS*) 

qui amenities _het_cre_a1 , `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z') ax1(`aa1')
esttab, unstack keep(pref:FS*) 

qui amenities _het_cre_ax1, `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z') ax1(`aa1' `xx1')
esttab, unstack keep(pref:FS*) 


// TABLE 7: no unobserved heterogeneity different instruments
qui amenities _nohet_zbud , `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars' zbaby) z(zbud)
esttab, unstack keep(pref:FS*) 

qui amenities _nohet_zbaby, `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars' zbud) z(zbaby)
esttab, unstack keep(pref:FS*) 

*amenities _nohet_znone, `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars' zbaby zbud)


// TABLE S1: preference estimates by age
unab xvars : age21-age25 lnw baby rktendv FStemp tzbud trpcito dzbud drpcito noord zuid oost wwperc vacatbb werkloosheid_perc dwerkloosheid
amenities _nohet_age20_26 if inrange(age, 20, 26), `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z')

unab xvars : age_d1 lnw baby rktendv FStemp tzbud trpcito dzbud drpcito noord zuid oost wwperc vacatbb werkloosheid_perc dwerkloosheid
amenities _nohet_age27_39 if inrange(age, 27, 39), `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z')

unab xvars : age_d3 lnw baby rktendv FStemp tzbud trpcito dzbud drpcito noord zuid oost wwperc vacatbb werkloosheid_perc dwerkloosheid
amenities _nohet_age40_60 if inrange(age, 40, 60), `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z')


exit


// MISC ROBUSTNESS CHECKS NOT IN PAPER
// different instruments & unobserved heterogeneity
amenities _het_cre_ax1_zbaby, `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars' zbud) ax1(`xx1' `aa1') z(zbaby)
amenities _het_cre_ax1_zbud , `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars' zbaby) ax1(`xx1' `aa1') z(zbud)
amenities _het_cre_ax1_znone, `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars' zbaby zbud) ax1(`xx1' `aa1')

// amenities: exclude public
unab amen1 : FIpdm FIpdd FIcs FIwtfactor FIpopkm2 FIpcito FIasch FIvsch FIrst
unab amen0 : FSpdm FSpdd FScs FSwtfactor FSpopkm2 FSpcito FSasch FSvsch FSrst
unab xvars : age21-age25 age_d1 age_d2 age_d3 lnw baby rktendv FStemp tzbud trpcito dzbud drpcito noord zuid oost FSpub
unab z     : zbud zbaby 

local aa1
qui foreach vv of varlist `amen0'{
	local aa1 `aa1' `vv'_1
}

local xx1
qui foreach vv of `xvars' {
	local xx1 `xx1' `vv'_1
}

amenities _het_cre_ax1_nopub, `bs' amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z') ax1(`xx1' `aa1') 
