clear all

//use ../temp_data
qui do crwork

// we use this below
program repost, eclass
	args bnew
	ereturn repost b = `bnew'
end

// define specification
unab xvars : age21-age25 age_d1 age_d2 age_d3 lnw baby rktendv FStemp tzbud trpcito   ///
               dzbud drpcito noord zuid oost wwperc vacatbb werkloosheid dwerkloosheid 
unab amen1 : FIpdm FIpdd FIcs FIwtfa FIpopkm2 FIpub FIpcito FIasch FIvsch FIrst
unab amen0 : FSpdm FSpdd FScs FSwtfa FSpopkm2 FSpub FSpcito FSasch FSvsch FSrst
unab z     : zbud zbaby 

local nx   : word count `xvars'
local na   : word count `amen0'
local nz   : word count `z'

// extract estimated parameters
est use _nohet
matrix b       = e(b)
matrix pref    = b[., "pref:"]
matrix psi     = b[., "psi:"]
matrix psi_A   = psi[., 1..`na']
matrix psi_X   = psi[., `na'+1..`na'+`nx']
matrix psi_Z   = psi[., `na'+`nx'+1..`na'+`nx'+`nz']
matrix psi_cst = psi[., `na'+`nx'+`nz'+1..`na'+`nx'+`nz'+1]
foreach vv in `amen1' {
	cap matrix alpha = alpha \ b[., "`vv':"]
	if (_rc) matrix alpha = b[., "`vv':"]
}
matrix alpha_A   = alpha[., 1..`na']
matrix alpha_X   = alpha[., `na'+1..`na' + `nx']
matrix alpha_mr  = alpha[., `na'+`nx'+1..`na'+`nx'+1]
matrix alpha_cst = alpha[., `na'+`nx'+2..`na'+`nx'+2]

// estimated distribution of A*|A,X
g mr = 0 
qui foreach vv in `amen1' {
	predict AX_`vv', outcome(`vv')
}

// counterfactual distribution of A*|A,X
// ------- choose one of the following -------
*matrix S0_alpha_A = alpha_A                                  // data (1st panel TABLES 9 & 10)
*matrix S0_alpha_A = diag(vecdiag(alpha_A))                  // only keep dependence between Aj* and Aj
matrix S0_alpha_A = J(rowsof(alpha_A),colsof(alpha_A),0)    // A* independent of A (2nd panel TABLES 9 & 10)
*matrix S0_alpha_A = -I(rowsof(alpha_A))                     // A* negatively correlated with A
// ------- choose one of the following -------
matrix S0_alpha_X = alpha_X                                  // data
*matrix S0_alpha_X = J(rowsof(alpha_X), colsof(alpha_X), 0)

matrix S0_alpha   = (S0_alpha_A, S0_alpha_X, alpha_mr, alpha_cst)
matrix S0_b       = (pref, psi, vec(S0_alpha')')
repost S0_b

// simulated distribution of A*|A,X
qui foreach vv in `amen1' {
	predict S0_AX_`vv', outcome(`vv')
}

// rescale simulated distribution of A*|A,X 
// so that it has the same distribution as the estimated one
mata: st_matrix("M_AX"   , mean(st_data(.,"AX*"))')
mata: st_matrix("S0_M_AX", mean(st_data(.,"S0_AX*"))')

corr AX_*, cov
matrix V_AX        = r(C)
matrix C_V_AX      = cholesky(V_AX)

corr S0_AX_*, cov
matrix S0_V_AX     = r(C)
matrix S0_C_V_AX   = cholesky(S0_V_AX)

matrix Mfact       = C_V_AX * inv(S0_C_V_AX)
matrix S_alpha_A   = Mfact * S0_alpha_A
matrix S_alpha_X   = Mfact * S0_alpha_X
matrix S_alpha_cst = Mfact * alpha_cst - Mfact * S0_M_AX + M_AX
matrix S_alpha     = (S_alpha_A, S_alpha_X, alpha_mr, S_alpha_cst)

matrix S_psi_A     = psi_A   + pref * (S_alpha_A   - alpha_A)
matrix S_psi_X     = psi_X   + pref * (S_alpha_X   - alpha_X)
matrix S_psi_cst   = psi_cst + pref * (S_alpha_cst - alpha_cst)
matrix S_psi       = (S_psi_A, S_psi_X, psi_Z, S_psi_cst)

matrix S_b         = (pref, S_psi, vec(S_alpha')')
repost S_b

predict S_psi, outcome(psi)
gen S_Pmov = normal(S_psi)
replace mr = normalden(S_psi) / S_Pmov
qui foreach vv in `amen1' {
	predict S_`vv', outcome(`vv')
}


// CHECK: are correlation matrices the same?
*corr AX_FI*
*corr S_FI*

// CHECK: are means the same?
*sum AX_FI*
*sum S_FI*

// Pmov per amenity quantile and quantile transition matrices: from A to A*|Q=1
local nq = 5

local FSpub FSpub
if (`nq' > 2) local amen0 : list amen0 - FSpub

// TABLE 9
qui foreach vv in `amen0' {
	local aj = substr("`vv'", 3, .)
	cap drop qaj _from _to* change up down

	pctile qaj = FS`aj', nq(`nq')
	levelsof qaj, local(q) sep(,)

	gen _from = 1 + irecode(FS`aj'  , `q')
	gen _to   = 1 + irecode(S_FI`aj', `q')
	
	gen change = _to~=_from
	gen up = _to>_from
	gen down = _to<_from
	
	tab _to, gen(_to)
	
	preserve
	collapse S_Pmov _to?* change up down, by(_from)
	format _to* S_Pmov change up down %9.3f
	noi di "Amenity: `aj'"
	noi list _from S_Pmov _to*, noobs
		
	mkmat S_Pmov, mat(M0)
	cap matrix SM = SM \ M0'	
	if _rc>0 matrix SM = M0'
	
	collapse change up down
	gen Pup = up/change
	mkmat change up down Pup, mat(QM0)
	cap matrix QM = QM \ QM0	
	if _rc>0 matrix QM = QM0
	
	restore
}

// TABLE 10
matrix list QM, f(%6.3f)


