use data/cross

gen prof = 1
rename wtfactor wtf
gen lcost = wtf*wage

bys brin year baby: egen lbabyabsschool = mean(lbabyabs)
bys brin year (baby): replace lbabyabsschool = lbabyabsschool[_N]
bys brin year sick: egen lsickabsschool = mean(lsickabs)
bys brin year (sick): replace lsickabsschool = lsickabsschool[_N]

collapse (sum) prof wtf baby wtfbaby sick wtfsick lcost (mean) denom stedhd schtype lbabyabsschool lsickabsschool vrouw age, by(brin year)
foreach vv of varlist baby sick wtfbaby wtfsick vrouw age {
	rename `vv' `vv'school
}
g wtfschool = wtf
// merge with support table and create ratio support / teacher
sort brin year
merge brin year using data/schools_supp
tab _merge
drop if _merge==2
foreach vv of varlist *_supp {
	replace `vv' = 0 if _merge==1
}
drop _merge
gen rst = wtf_supp / wtf

// merge in municipality and region identifiers
sort brin year
merge brin using other/final
tab _merge
drop if _merge == 2
drop if gemeente == "" | onderwijsgebied == ""
drop _merge

// merge in student counts
sort brin year
merge brin year using other/aantal92_04
tab _merge
drop if _merge == 2
drop _merge


// merge in popkm2
sort brin 
merge brin using other/brinpopkm2
tab _merge
drop if _merge == 2
drop _merge

// merge in test score data
sort brin year
merge brin year using data/test
tab _merge
drop if _merge == 2
drop _merge

// student composition info
gen schoolsize = aantal1 + aantal2 + aantal3 + aantal4 + aantal5
gen wschoolsize = aantal1 + 1.25 * aantal2 + 1.4 * aantal3 + 1.7 * aantal4 + 1.9 * aantal5
drop if schoolsize < 10
label var schoolsize "# pupils in school"
label var wschoolsize "# weighted pupils in school"

gen pnd = aantal1 / schoolsize
gen pdd = (aantal2 + aantal3) / schoolsize
gen pdm = (aantal4 + aantal5) / schoolsize
label var pnd "fraction of non-disadvantaged dutch pupils"
label var pdd "fraction of disadvantaged dutch pupils"
label var pdm "fraction of disadvantaged migrant pupils"
drop aantal1-aantal5

// pupil-teacher ratio
gen csize = schoolsize / wtf

/*
// drop schools with extreme pupil/teacher ratios
gen x = (inrange(csize, 5, 35) == 0)
bys brin: egen sx = sum(x)
drop if sx > 0
drop x sx
*/

// drop school with gaps
bysort brin (year) : gen x = sum(year ~= year[_n - 1] + 1)
bysort brin (year) : replace x = x[_N]
drop if x > 1
drop x

// repair 2000
bysort brin (year): gen newstedhd = stedhd[_n - 1] if year == 2000 & _n > 1
bysort brin (year): replace newstedhd = stedhd[_n + 1] if year == 2000 & _n == 1
replace stedhd = newstedhd if year == 2000
drop newstedhd
rename stedhd urban
gen public = (denom == 1)

// create lags and leads
egen sid = group(brin)
tsset sid year
foreach vv of var pnd pdd pdm *size public urban lcost prof wtf sickschool wtfsickschool wtfschool vrouwschool ageschool rst popkm2 {
	gen L`vv' = l.`vv'
	gen F`vv' = f.`vv'
}
foreach vv of var *cito *math *lang {
	gen L`vv' = l.`vv'
}
drop sid

/*
// identify outliers with respect to change in wschoolsize
gen dwsch = (Fwschoolsize - wschoolsize) / wschoolsize
su dwsch, det
drop if (dwsch < r(p1) | dwsch > r(p99)) & dwsch ~= .
drop dwsch
*/

// create instruments (at school level)
reg wtf wschoolsize
gen pwtf = _b[_cons] + _b[wschoolsize] * Fwschoolsize
gen z1 = pwtf - wtf
gen z2 = pwtf / wtf
gen zbud = Fwschoolsize - wschoolsize

// region variables
rename provincie region
label var region "Region (provincie)"
rename onderwijs district
label var district "District (onderwijsgebied)"
rename gemeente  town
label var town "Municipality (gemeente)"
bys district year: gen district_Ns = _N
bys town year: gen town_Ns = _N

// create regional controls
foreach vv of varlist z1 zbud pwtf wtf schoolsize wschoolsize {
	bys district year: egen Sdistrict = sum(`vv')
	bys town year: egen Stown = sum(`vv')
	gen town_`vv' = Stown - `vv'
	gen district_`vv' = Sdistrict - `vv' - town_`vv'
	gen mdistrict_`vv' = district_`vv' / (district_Ns - (district_Ns > 1))
	gen mtown_`vv' = town_`vv' / (town_Ns - (town_Ns > 1))
	drop Stown Sdistrict
}

foreach vv of varlist district town {
	gen `vv'_z2 = `vv'_pwtf / `vv'_wtf
	drop `vv'_pwtf `vv'_wtf

	// calculate rank in region
	foreach xx of varlist pdd pdm pcito csize {
		bys `vv' year: egen `vv'_rank_`xx' = rank(`xx')
		bys `vv' year: egen max = max(`vv'_rank_`xx')
		replace `vv'_rank_`xx' = `vv'_rank_`xx' / max
		drop max
	}
}

sort brin year
compress
save data/schools, replace
