// F: forward looking, I: at the individual level, S: at the school level

// put pieces together
use data/cross, clear

sort brin year
merge brin year using data/schools
keep if _merge == 3
drop _merge

gen age2 = age^2
gen lnw = ln(wage)
replace temp = temp - 1

// delete indiv after the first time they leave the teacher labor market (hence no gap)
qui bys stamnr (year): gen quit = (_n > 1) * (year ~= year[_n - 1] + 1)
qui bys stamnr (year): replace quit = sum(quit)
tab quit
drop if quit > 0
drop quit

replace popkm2 = ln(popkm2)
replace Fpopkm2 = ln(Fpopkm2)

replace Fwtfsickschool = Fwtfsickschool / Fwtfschool
replace wtfsickschool = wtfsickschool / wtfschool

egen gtown = group(town)
egen gdistrict = group(district)
egen gregion = group(region)
tsset stamnr year
renpfix F FS
foreach vv of varlist pdm pdd pnd csize lnw wtfactor temp public urban wschoolsize lcost gregion gdistrict gtown wtf wtfsickschool prof ageschool vrouwschool rst wgnr popkm2 {
	gen FI`vv' = f.`vv'
}

rename FSwschoolsize FSbud
rename FIwschoolsize FIbud
gen FIpcito = f.Lpcito
gen FSpcito = pcito

// we assume that teachers who change job base their mobility decisions on the current value of (temp,wtf,lnw)
gen FStemp = temp*(move==1) + FItemp*(move==0) 
gen FSwtfactor = wtfactor*(move==1) + FIwtfactor*(move==0)
gen FSlnw = lnw

drop L* district_Ns town_Ns mdistrict_z1 mtown_z1 town_schoolsize district_schoolsize mdistrict_schoolsize mtown_schoolsize       /*
*/   mdistrict_pwtf mtown_pwtf mdistrict_wtf mtown_wtf district_z2 datumsf0 schtype denom stedhd bapo datumdv0 wage cs       /*
*/   ten0 region district town postcode plang pmath girl mcito mlang mmath qmcito qmlang     /*
*/   qmmath schoolsize district_rank_pdd district_rank_pdm district_rank_csize town_z2       /*
*/   town_rank_pdd town_rank_pdm town_rank_csize

compress

save data/work, replace

// from work.dta, make two tables, one with and one without pcito

use data/work
recode age (min/19=20) (20/29=20) (30/39=30) (40/49=40) (50/max=50), gen(agecat)
qui tab agecat, gen(age_d)
rename town_zbud tzbud
rename town_rank_pcito trpcito
rename district_zbud dzbud
rename district_rank_pcito drpcito
rename FIcsize FIcs
rename FIurban FIurb
rename FIpublic FIpub
rename FIageschool FIasch
rename FIvrouwschool FIvsch
rename FScsize FScs
rename FSurban FSurb
rename FSpublic FSpub
rename FSageschool FSasch
rename FSvrouwschool FSvsch
gen zbaby = wtfbabyschool-wtfbaby
unab z : zbud zbaby
unab xvars : age_d* vrouw lnw baby rktendv FStemp tzbud trpcito dzbud drpcito
unab amen1 : FIpdm FIpdd FIcs FIwtfa FIpopkm2 FIpub FIpcito FIasch FIvsch FIrst FIwtfsickschool
unab amen0 : FSpdm FSpdd FScs FSwtfa FSpopkm2 FSpub FSpcito FSasch FSvsch FSrst FSwtfsickschool
local nx : word count `xvars'
local na : word count `amen0'
rename move1 q
keep q `z' `amen1' `amen0' `xvars' stamnr year brin age
qui reg q `z' `amen1' `amen0' `xvars'
keep if e(sample)==1
su zbud, det
keep if inrange(zbud,r(p1),r(p99))==1
compress
save data/table, replace

use data/work, clear
recode age (min/19=20) (20/29=20) (30/39=30) (40/49=40) (50/max=50), gen(agecat)
qui tab agecat, gen(age_d)
rename town_zbud tzbud
rename district_zbud dzbud
rename FIcsize FIcs
rename FIurban FIurb
rename FIpublic FIpub
rename FIageschool FIasch
rename FIvrouwschool FIvsch
rename FScsize FScs
rename FSurban FSurb
rename FSpublic FSpub
rename FSageschool FSasch
rename FSvrouwschool FSvsch
gen zbaby = wtfbabyschool-wtfbaby
unab z : zbud zbaby
unab xvars : age_d* vrouw lnw baby rktendv FStemp tzbud dzbud 
unab amen1 : FIpdm FIpdd FIcs FIwtfa FIurb FIpub FIasch FIvsch FIrst FIwtfsickschool
unab amen0 : FSpdm FSpdd FScs FSwtfa FSurb FSpub FSasch FSvsch FSrst FSwtfsickschool
local nx : word count `xvars'
local na : word count `amen0'
rename move1 q
keep q `z' `amen1' `amen0' `xvars' stamnr year brin age
qui reg q `z' `amen1' `amen0' `xvars'
keep if e(sample)==1
su zbud, det
keep if inrange(zbud,r(p1),r(p99))==1
compress
save data/table_nopcito, replace

