// -estout- is handy:
cap which estout
if (_rc) ssc install estout

cap program drop lik
program define lik
args lnf xb a0 a1 a2
tempvar index
	qui gen double `index' = `a0' + `a1' * (`xb' + refvar) + `a2' * (`xb' + refvar)^2
	qui replace `lnf' = q * `index' - log(1 + exp(`index'))
	//qui replace `lnf' = log(normal(`index'))*q+log(1-normal(`index'))*(1-q)
end


cap program drop est2step
program define est2step, eclass
syntax [if], AMEN1(varlist) [AMEN0(varlist) Z(varlist) XVARS(varlist) AX1(varlist) NOAHET]
	marksample touse
	//markout `touse' `amen1' `amen0' `xvars' `z' `ax1'
	tempname alpha ALPHA psi pref b 
	tempvar xb

	// estimate mobility equation + mill's ratio (mr)
	qui probit q `amen0' `xvars' `z' `ax1' if `touse'
	matrix `psi' = e(b)
	matrix coleq `psi' = psi
	predict `xb', xb
	gen mr = normalden(`xb') / normal(`xb')

	// estimate offer equations
	if ("`noahet'"!="") local ax1
	qui foreach vv of varlist `amen1' {
		reg `vv' `amen0' `xvars' mr `ax1' if q==1 & `touse'
		matrix `b' = e(b)
		matrix coleq `b' = `vv'
		cap matrix `alpha' = `alpha' , `b'
		if (_rc) matrix `alpha' = `b'
	}

	// recuperate preferences
	local na : word count `amen0'
	mata: st_matrix("`ALPHA'", rowshape(st_matrix("`alpha'"), `na')) 
	matrix `pref' = `psi'[1,1..`na']*inv(`ALPHA'[1...,1..`na'] - diag(J(1,`na',1)))
	matrix colnames `pref' = `amen0'
	matrix coleq `pref' = pref

	// return everything in one coef vector
	matrix `b' = `pref', `psi', `alpha'
	ereturn post `b', esample(`touse')
	ereturn local cmd="bootstrap"
	//estout, unstack cells(b(fmt(3)))   // for vertical output use: ereturn display
	cap drop mr
end



// little helper program to do the calculations and make a table
// we gain little, but it makes the code for running different
// specifications a bit cleaner:
// . amenities foobar, amen1(`amen1') amen0(`amen0') xvars(`xvars') z(`z')
// saves the results in 'foobar.ster' which we can load with
// . estimates use foobar

cap program drop amenities
program amenities
syntax [anything] [if] [, BS] *
	marksample touse
	// are we bootstrapping? if so, std.error in table
	if ("`bs'"!="") {
		local bootstrap "bootstrap , reps(499) cluster(schoolid) notable: "
		local se "se(par)) starlevels(* 0.10 ** 0.05 *** 0.01"
	}
	// estimate
	`bootstrap' est2step if `touse', `options'
	// save and print table
	if ("`anything'"!="") est save `anything', replace
	estout, unstack cells(b(fmt(3) star) `se')
end
